@@ -2,7 +2,7 @@ package t::Util;
 use strict;
 use warnings;
 use utf8;
-use 5.10.0;
+use feature qw/state/;
 
 use Test::Mock::Furl;
 
